import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

import projen._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@pepperize/projen-awscdk-construct",
    "0.0.444",
    __name__[0:-6],
    "projen-awscdk-construct@0.0.444.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
